==> mixmeta_1.0.5.tar.gz: mixmeta/NEWS.md <==
-----------------------------------

### Changes in mixmeta 1.0.4 (29 Aug 2019)

#### Minor changes

  * Fixed authorship in main reference.

-----------------------------------

### Changes in mixmeta 1.0.3 (21 Aug 2019)

#### Minor changes

  * Change in examples.
  
  * Updated references.

-----------------------------------

### Changes in mixmeta 1.0.1 (20 Aug 2019)

#### Major changes

  * Package now in CRAN.

#### Minor changes

  * Fixed bug in getFixTerms().

  * Fixed bug in getContrXlev().

-----------------------------------

### Changes in mixmeta 0.2.3 (31 July 2019)

#### Minor changes

  * Minor changes to the README.
  
-----------------------------------

### Changes in mixmeta 0.2.2 (25 July 2019)

#### Minor changes

  * Fixed bug in getInitPsi() and getPisFix().
  
  * Reduction of examples in gliomas to match CRAN requirements.
  
-----------------------------------

### Changes in mixmeta 0.2.1  (25 July 2019)

#### Minor changes

  * Changes to example in dataset alcohol to show use of functions in formula.
  
  * Minor changes to the documentation.

-----------------------------------

### Changes in mixmeta 0.2.0  (17 July 2019)

#### Major changes

  * Getting the package ready for CRAN.

#### Minor changes

  * Minor changes to the documentation.

-----------------------------------

### Changes in mixmeta 0.1.9  (11 July 2019)

#### Minor changes

  * Fixed problem with terms object. Now returned only for fixed-effects part,
    and a new method function can extract either that or the full one.

-----------------------------------

### Changes in mixmeta 0.1.8  (26 June 2019)

#### Minor changes

  * Fixed bug in mvmetaSim() when addSlist used.
  
  * Change in the usage of blup.mixmeta(), with "residual"" replacing
    "deviation" in the argument 'type'.

-----------------------------------

### Changes in mixmeta 0.1.7  (04 June 2019)

#### Minor changes

  * Minor fixes.

-----------------------------------

### Changes in mixmeta 0.1.6  (04 June 2019)

#### Minor changes

  * Minor fixes in NEWS.

-----------------------------------

### Changes in mixmeta 0.1.5  (04 June 2019)

#### Major changes

  * Added 'type' argument in blup() to produce predictions of either the
    outcomes (default) or random-effects deviations.
      
#### Minor changes

  * Minor bug fixed in getBSCov().
    
  * Argument 'env' added to getRandom() to assign an environment to the 
    random-effects formula(e).
      
  * Minor changes to the usage of predict() and blup().
    
  * NEWS added to the package. 
    
  * Documentation changed accordingly.

-----------------------------------

### Changes in mixmeta 0.1.4 (31 May 2019)

#### Major changes

  * Package now in GitHub (https://github.com/gasparrini/mixmeta).

-----------------------------------

### New package mixmeta 0.0.1 (06 December 2018)

-----------------------------------

==> mixmeta_1.0.7.tar.gz: mixmeta/NEWS.md <==
-----------------------------------

### Changes in mixmeta 1.0.7 (09 Dec 2019)

#### Minor changes

  * Fixed problems with long-running examples preventing passing CRAN tests.

-----------------------------------

### Changes in mixmeta 1.0.6 (09 Dec 2019)

#### Minor changes

  * Change in mixmeta() to comply with changes in R 4.0.0 regarding the new
    class for matrix objects, now including 'array'.

-----------------------------------

### Changes in mixmeta 1.0.5 (11 Nov 2019)

#### Minor changes

  * Main reference updated.

-----------------------------------

### Changes in mixmeta 1.0.4 (29 Aug 2019)

#### Minor changes

  * Fixed authorship in main reference.

-----------------------------------

### Changes in mixmeta 1.0.3 (21 Aug 2019)

#### Minor changes

  * Change in examples.
  
  * Updated references.

-----------------------------------

### Changes in mixmeta 1.0.1 (20 Aug 2019)

#### Major changes

  * Package now in CRAN.

#### Minor changes

  * Fixed bug in getFixTerms().

  * Fixed bug in getContrXlev().

-----------------------------------

### Changes in mixmeta 0.2.3 (31 July 2019)

#### Minor changes

  * Minor changes to the README.
  
-----------------------------------

### Changes in mixmeta 0.2.2 (25 July 2019)

#### Minor changes

  * Fixed bug in getInitPsi() and getPisFix().
  
  * Reduction of examples in gliomas to match CRAN requirements.
  
-----------------------------------

### Changes in mixmeta 0.2.1  (25 July 2019)

#### Minor changes

  * Changes to example in dataset alcohol to show use of functions in formula.
  
  * Minor changes to the documentation.

-----------------------------------

### Changes in mixmeta 0.2.0  (17 July 2019)

#### Major changes

  * Getting the package ready for CRAN.

#### Minor changes

  * Minor changes to the documentation.

-----------------------------------

### Changes in mixmeta 0.1.9  (11 July 2019)

#### Minor changes

  * Fixed problem with terms object. Now returned only for fixed-effects part,
    and a new method function can extract either that or the full one.

-----------------------------------

### Changes in mixmeta 0.1.8  (26 June 2019)

#### Minor changes

  * Fixed bug in mvmetaSim() when addSlist used.
  
  * Change in the usage of blup.mixmeta(), with "residual"" replacing
    "deviation" in the argument 'type'.

-----------------------------------

### Changes in mixmeta 0.1.7  (04 June 2019)

#### Minor changes

  * Minor fixes.

-----------------------------------

### Changes in mixmeta 0.1.6  (04 June 2019)

#### Minor changes

  * Minor fixes in NEWS.

-----------------------------------

### Changes in mixmeta 0.1.5  (04 June 2019)

#### Major changes

  * Added 'type' argument in blup() to produce predictions of either the
    outcomes (default) or random-effects deviations.
      
#### Minor changes

  * Minor bug fixed in getBSCov().
    
  * Argument 'env' added to getRandom() to assign an environment to the 
    random-effects formula(e).
      
  * Minor changes to the usage of predict() and blup().
    
  * NEWS added to the package. 
    
  * Documentation changed accordingly.

-----------------------------------

### Changes in mixmeta 0.1.4 (31 May 2019)

#### Major changes

  * Package now in GitHub (https://github.com/gasparrini/mixmeta).

-----------------------------------

### New package mixmeta 0.0.1 (06 December 2018)

-----------------------------------
